@@ -17,12 +17,21 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 该地域尚未开放，请选择其他地域。
+AUTHFAILURE_INVALIDREGION = 'AuthFailure.InvalidRegion'
+
 # 操作失败。
 FAILEDOPERATION = 'FailedOperation'
 
 # 创建镜像失败。
 FAILEDOPERATION_CREATEBLUEPRINTFAILED = 'FailedOperation.CreateBlueprintFailed'
 
+# 创建云硬盘失败。
+FAILEDOPERATION_CREATEDISKSFAILED = 'FailedOperation.CreateDisksFailed'
+
+# 创建实例失败。
+FAILEDOPERATION_CREATEINSTANCESFAILED = 'FailedOperation.CreateInstancesFailed'
+
 # 对密钥对的创建操作失败。
 FAILEDOPERATION_CREATEKEYPAIRFAILED = 'FailedOperation.CreateKeyPairFailed'
 
@@ -44,6 +53,12 @@ FAILEDOPERATION_DESCRIBEINSTANCESRETURNABLEERROR = 'FailedOperation.DescribeInst
 # 查询流量包失败。
 FAILEDOPERATION_DESCRIBEINSTANCESTRAFFICPACKAGESFAILED = 'FailedOperation.DescribeInstancesTrafficPackagesFailed'
 
+# 查询资源返回了不符合要求内容。
+FAILEDOPERATION_DESCRIBERESOURCESRETURNABLEERROR = 'FailedOperation.DescribeResourcesReturnableError'
+
+# 销毁资源失败，请稍后重新操作。
+FAILEDOPERATION_DESTROYRESOURCESFAILED = 'FailedOperation.DestroyResourcesFailed'
+
 # 对防火墙规则的操作失败。
 FAILEDOPERATION_FIREWALLRULESOPERATIONFAILED = 'FailedOperation.FirewallRulesOperationFailed'
 
@@ -53,14 +68,20 @@ FAILEDOPERATION_IMPORTKEYPAIRFAILED = 'FailedOperation.ImportKeyPairFailed'
 # 对实例的操作失败。
 FAILEDOPERATION_INSTANCEOPERATIONFAILED = 'FailedOperation.InstanceOperationFailed'
 
+# 命令无法找到。
+FAILEDOPERATION_INVALIDCOMMANDNOTFOUND = 'FailedOperation.InvalidCommandNotFound'
+
 # 退还资源失败。
 FAILEDOPERATION_ISOLATERESOURCESFAILED = 'FailedOperation.IsolateResourcesFailed'
 
 # 变更实例套餐失败。
 FAILEDOPERATION_MODIFYINSTANCESBUNDLEFAILED = 'FailedOperation.ModifyInstancesBundleFailed'
 
-# 续费实例失败。
-FAILEDOPERATION_RENEWINSTANCESFAILED = 'FailedOperation.RenewInstancesFailed'
+# 变更资源属性失败，请稍后重新操作。
+FAILEDOPERATION_MODIFYRESOURCESATTRIBUTEFAILED = 'FailedOperation.ModifyResourcesAttributeFailed'
+
+# 续费资源失败。
+FAILEDOPERATION_RENEWRESOURCESFAILED = 'FailedOperation.RenewResourcesFailed'
 
 # 请求错误。
 FAILEDOPERATION_REQUESTERROR = 'FailedOperation.RequestError'
@@ -68,6 +89,9 @@ FAILEDOPERATION_REQUESTERROR = 'FailedOperation.RequestError'
 # 快照操作失败。
 FAILEDOPERATION_SNAPSHOTOPERATIONFAILED = 'FailedOperation.SnapshotOperationFailed'
 
+# 调用计费网关服务失败，请稍后重新操作操作。
+FAILEDOPERATION_TRADECALLBILLINGGATEWAYFAILED = 'FailedOperation.TradeCallBillingGatewayFailed'
+
 # 计费询价失败。
 FAILEDOPERATION_TRADEGETPRICEFAILED = 'FailedOperation.TradeGetPriceFailed'
 
@@ -131,6 +155,9 @@ INVALIDPARAMETER_BUNDLEANDBLUEPRINTNOTMATCH = 'InvalidParameter.BundleAndBluepri
 # 产品未定义的套餐 ID。
 INVALIDPARAMETER_BUNDLEIDNOTFOUND = 'InvalidParameter.BundleIdNotFound'
 
+# 参数冲突。
+INVALIDPARAMETER_CONFLICT = 'InvalidParameter.Conflict'
+
 # 参数非法，Filter 参数中的 Values 取值数量超过允许的最大数量。
 INVALIDPARAMETER_FILTERVALUELIMITEXCEEDED = 'InvalidParameter.FilterValueLimitExceeded'
 
@@ -158,6 +185,9 @@ INVALIDPARAMETER_INVALIDFILTERNOTDICT = 'InvalidParameter.InvalidFilterNotDict'
 # 参数非法，Filter 参数中有不支持的 Name。
 INVALIDPARAMETER_INVALIDFILTERNOTSUPPORTEDNAME = 'InvalidParameter.InvalidFilterNotSupportedName'
 
+# 必须要指定一个要修改的属性。
+INVALIDPARAMETER_MUSTSPECIFYONEATTRIBUTETOMODIFY = 'InvalidParameter.MustSpecifyOneAttributeToModify'
+
 # 参数非法，每次只能修改一个属性。
 INVALIDPARAMETER_ONLYALLOWMODIFYONEATTRIBUTE = 'InvalidParameter.OnlyAllowModifyOneAttribute'
 
@@ -182,9 +212,18 @@ INVALIDPARAMETERVALUE_BUNDLEANDBLUEPRINTNOTMATCH = 'InvalidParameterValue.Bundle
 # 云联网实例ID格式非法。
 INVALIDPARAMETERVALUE_CCNIDMALFORMED = 'InvalidParameterValue.CcnIdMalformed'
 
+# 客户令牌长度超出限制。
+INVALIDPARAMETERVALUE_CLIENTTOKENTOOLONG = 'InvalidParameterValue.ClientTokenTooLong'
+
 # 参数值非法，云硬盘备份点 ID 格式非法。
 INVALIDPARAMETERVALUE_DISKBACKUPIDMALFORMED = 'InvalidParameterValue.DiskBackupIdMalformed'
 
+# 指定的云盘备份点名称不可大于最大长度。
+INVALIDPARAMETERVALUE_DISKBACKUPNAMETOOLONG = 'InvalidParameterValue.DiskBackupNameTooLong'
+
+# 云硬盘的可用区与实例的可用区不匹配。
+INVALIDPARAMETERVALUE_DISKINSTANCEZONENOTMATCH = 'InvalidParameterValue.DiskInstanceZoneNotMatch'
+
 # 磁盘名称长度超出限制。
 INVALIDPARAMETERVALUE_DISKNAMETOOLONG = 'InvalidParameterValue.DiskNameTooLong'
 
@@ -224,9 +263,15 @@ INVALIDPARAMETERVALUE_INVALIDBUNDLE = 'InvalidParameterValue.InvalidBundle'
 # 控制台显示类型不合法。
 INVALIDPARAMETERVALUE_INVALIDCONSOLEDISPLAYTYPES = 'InvalidParameterValue.InvalidConsoleDisplayTypes'
 
+# 当前实例到期时间不能早于云硬盘到期时间。
+INVALIDPARAMETERVALUE_INVALIDCURINSTANCEDEADLINE = 'InvalidParameterValue.InvalidCurInstanceDeadline'
+
 # 参数值非法，磁盘 ID 格式非法。
 INVALIDPARAMETERVALUE_INVALIDDISKIDMALFORMED = 'InvalidParameterValue.InvalidDiskIdMalformed'
 
+# 云硬盘类型非法。
+INVALIDPARAMETERVALUE_INVALIDDISKTYPE = 'InvalidParameterValue.InvalidDiskType'
+
 # 设置是否使用默认密钥对登录的值不正确。
 INVALIDPARAMETERVALUE_INVALIDINSTANCELOGINKEYPAIRPERMITLOGIN = 'InvalidParameterValue.InvalidInstanceLoginKeyPairPermitLogin'
 
@@ -278,6 +323,24 @@ INVALIDPARAMETERVALUE_NOTALLOWTOCHANGEPLATFORMTYPE = 'InvalidParameterValue.NotA
 # 参数值非法，不在合法范围内。
 INVALIDPARAMETERVALUE_OUTOFRANGE = 'InvalidParameterValue.OutOfRange'
 
+# 实例操作系统不支持该文件系统。
+INVALIDPARAMETERVALUE_PLATFORMTYPENOTSUPPORTFILESYSTEM = 'InvalidParameterValue.PlatformTypeNotSupportFileSystem'
+
+# 实例操作系统不支持指定挂载点。
+INVALIDPARAMETERVALUE_PLATFORMTYPENOTSUPPORTMOUNTPOINT = 'InvalidParameterValue.PlatformTypeNotSupportMountPoint'
+
+# 地域不存在。
+INVALIDPARAMETERVALUE_REGIONNOTFOUND = 'InvalidParameterValue.RegionNotFound'
+
+# 地域不匹配。
+INVALIDPARAMETERVALUE_REGIONNOTMATCH = 'InvalidParameterValue.RegionNotMatch'
+
+# 不支持的地域。
+INVALIDPARAMETERVALUE_REGIONNOTSUPPORTED = 'InvalidParameterValue.RegionNotSupported'
+
+# 该地域不可用。
+INVALIDPARAMETERVALUE_REGIONUNAVAILABLE = 'InvalidParameterValue.RegionUnavailable'
+
 # 参数值非法，快照 ID 格式非法。
 INVALIDPARAMETERVALUE_SNAPSHOTIDMALFORMED = 'InvalidParameterValue.SnapshotIdMalformed'
 
@@ -293,12 +356,18 @@ INVALIDPARAMETERVALUE_ZONEINVALID = 'InvalidParameterValue.ZoneInvalid'
 # 超过配额限制。
 LIMITEXCEEDED = 'LimitExceeded'
 
-# 实例挂载数据盘配额不足，无法挂载磁盘。
+# 实例挂载数据盘配额不足，无法挂载云硬盘。
 LIMITEXCEEDED_ATTACHDATADISKQUOTALIMITEXCEEDED = 'LimitExceeded.AttachDataDiskQuotaLimitExceeded'
 
+# 配额不足，当前自定义镜像配额不允许创建新的自定义镜像。
+LIMITEXCEEDED_BLUEPRINTQUOTALIMITEXCEEDED = 'LimitExceeded.BlueprintQuotaLimitExceeded'
+
 # 超过磁盘备份点配额限制。
 LIMITEXCEEDED_DISKBACKUPQUOTALIMITEXCEEDED = 'LimitExceeded.DiskBackupQuotaLimitExceeded'
 
+# 当前配额不足，无法创建新的云硬盘。
+LIMITEXCEEDED_DISKQUOTALIMITEXCEEDED = 'LimitExceeded.DiskQuotaLimitExceeded'
+
 # 超过防火墙规则配额。
 LIMITEXCEEDED_FIREWALLRULESLIMITEXCEEDED = 'LimitExceeded.FirewallRulesLimitExceeded'
 
@@ -317,6 +386,9 @@ LIMITEXCEEDED_SNAPSHOTQUOTALIMITEXCEEDED = 'LimitExceeded.SnapshotQuotaLimitExce
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 必须传入参数Period或CurInstanceDeadline。
+MISSINGPARAMETER_MISSINGPARAMETERPERIODCURINSTANCEDEADLINE = 'MissingParameter.MissingParameterPeriodCurInstanceDeadline'
+
 # 该实例不支持升级套餐操作。
 OPERATIONDENIED_BUNDLENOTSUPPORTMODIFY = 'OperationDenied.BundleNotSupportModify'
 
@@ -344,6 +416,9 @@ OPERATIONDENIED_INSTANCECREATING = 'OperationDenied.InstanceCreating'
 # 禁止对实例进行操作，实例最近一次的操作尚在进行中。
 OPERATIONDENIED_INSTANCEOPERATIONINPROGRESS = 'OperationDenied.InstanceOperationInProgress'
 
+# 禁止创建快照。
+OPERATIONDENIED_OPERATIONDENIEDCREATESNAPSHOT = 'OperationDenied.OperationDeniedCreateSnapshot'
+
 # 使用存储型套餐的实例不支持创建快照。
 OPERATIONDENIED_OPERATIONDENIEDCREATESNAPSHOTFORSTORAGEBUNDLE = 'OperationDenied.OperationDeniedCreateSnapshotForStorageBundle'
 
@@ -536,6 +611,9 @@ UNSUPPORTEDOPERATION_SNAPSHOTBUSY = 'UnsupportedOperation.SnapshotBusy'
 # 系统忙。
 UNSUPPORTEDOPERATION_SYSTEMBUSY = 'UnsupportedOperation.SystemBusy'
 
+# 实例上腾讯云助手 agent 不在线。
+UNSUPPORTEDOPERATION_TATAGENTNOTONLINE = 'UnsupportedOperation.TatAgentNotOnline'
+
 # Windows实例不支持绑定密钥对。
 UNSUPPORTEDOPERATION_WINDOWSNOTALLOWTOASSOCIATEKEYPAIR = 'UnsupportedOperation.WindowsNotAllowToAssociateKeyPair'
 
